A compatibility fix to allow [whisperx](https://github.com/m-bain/whisperX) to work with other packages that require numpy>2. Should no longer be required once pull requests on the main package are accepted.

Pypi link: https://pypi.org/project/whisperx-numpy2-compatibility/
